@@ -1,4 +1,4 @@
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 df = data.frame(
   Design = c("Simple Experiments", "2-Level CRTs", "2-Level MRTs",
              "3-Level CRTs", "3-Level MRTs",
@@ -14,16 +14,18 @@ df = data.frame(
                      "re", "re")
   
 )
+names(df) <- c("Design", "OD Function", "Power Function", "RE Function")
 library(knitr)
 kable(df,
       caption = "Functions for Designs Detecting Main Effects")
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 df = data.frame(
   Design = c("Simple Experiments", "2-Level CRTs", "2-Level MRTs"),
   OD_Function = c("od.1.111", "od.2.221", "od.2m.111"),
   Power_Function = c("power.1.111", "power.2.221", "power.2m.111")
 )
+names(df) <- c("Design", "OD Function", "Power Function")
 library(knitr)
 kable(df,
       caption = "Functions for Designs Detecting Mediation Effects (In Preparation)")
@@ -41,8 +43,9 @@ myod1 <- od.2(icc = 0.2, r12 = 0.5, r22 = 0.5, c1 = 1, c2 = 5, c1t = 1, c2t = 50
 
 ## ----fig.width = 5, fig.height = 5--------------------------------------------
  # constrained optimal design with n = 20
-myod2 <- od.2(icc = 0.2, r12 = 0.5, r22 = 0.5, c1 = 1, c2 = 5, c1t = 1, c2t = 50,
-              plot.by = list(p = "p"), n = 20, varlim = c(0.005, 0.030))
+myod2 <- od.2(icc = 0.2, r12 = 0.5, r22 = 0.5, c1 = 1, c2 = 5, c1t = 1, 
+              c2t = 50, plot.by = list(p = "p"), n = 20, 
+              varlim = c(0.005, 0.030))
  # myod2$out # output
  # myod2$par # parameters used in the calculation.
 
@@ -203,3 +206,14 @@ myre <- re(od = myod1, subod= myod4)
 # ?od.3m
 # ?od.4m
 
+## -----------------------------------------------------------------------------
+# Optimal sample allocation and statistical power for randomized controlled trials
+myod <- od.1.111(a = .3, b = .5, c1 = 10, c1t = 100, verbose = FALSE)
+mypower <- power.1.111(expr = myod, power = .8)
+# mypower
+
+# Conventional power analyses
+mypower <- power.1.111(cost.model = FALSE, a = .3, b = .5, test = "joint",
+                        power = .8, p =.5)
+# mypower
+
